pub enum EventsRequest {
FunctionRegistered {
responder: EventsFunctionRegisteredResponder,
},
FunctionsCleared {
control_handle: EventsControlHandle,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: EventsControlHandle,
method_type: MethodType,
},
}Expand description
Events protocol that is used as a callback to inform the client of the completion of various server-side events. This callback interface can be registered using the SetStateChangeListener method on the Device protocol.
Variants
FunctionRegistered
Invoked when a function registers
Fields

responder: EventsFunctionRegisteredResponderFunctionsCleared
Invoked when all functions have been cleared.
Fields

control_handle: EventsControlHandle#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: EventsControlHandle
method_type: MethodTypeImplementations
Sourceimpl EventsRequest
impl EventsRequest
pub fn into_function_registered( self, ) -> Option<EventsFunctionRegisteredResponder>
pub fn into_functions_cleared(self) -> Option<EventsControlHandle>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL