pub struct DeviceProxy { /* private fields */ }Implementations
Sourceimpl DeviceProxy
impl DeviceProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.usb.peripheral/Device.
Sourcepub fn take_event_stream(&self) -> DeviceEventStream
pub fn take_event_stream(&self) -> DeviceEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_configuration(
&self,
) -> QueryResponseFut<DeviceGetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn get_configuration( &self, ) -> QueryResponseFut<DeviceGetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
Retrieves the current device descriptor and active configuration descriptors.
Returns the active USB device descriptor and all associated configuration descriptors registered with the peripheral device manager.
- error:
ZX_ERR_BAD_STATE: The peripheral device has not been configured.
Sourcepub fn set_configuration(
&self,
device_desc: &DeviceDescriptor,
config_descriptors: &[Vec<FunctionDescriptor>],
) -> QueryResponseFut<DeviceSetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn set_configuration( &self, device_desc: &DeviceDescriptor, config_descriptors: &[Vec<FunctionDescriptor>], ) -> QueryResponseFut<DeviceSetConfigurationResult, DefaultFuchsiaResourceDialect> ⓘ
Sets the device’s descriptors, adds the functions and creates the child devices for the configuration’s interfaces. At least one function descriptor must be provided.
Sourcepub fn clear_functions(
&self,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect> ⓘ
pub fn clear_functions( &self, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect> ⓘ
Tells the device to remove the child devices for the configuration’s interfaces
and reset the list of functions to empty.
The caller should wait for the FunctionsCleared event.
Sourcepub fn set_state_change_listener(
&self,
listener: ClientEnd<EventsMarker>,
) -> Result<(), Error>
pub fn set_state_change_listener( &self, listener: ClientEnd<EventsMarker>, ) -> Result<(), Error>
Adds a state change listener that is invoked when a state change completes.