pub struct EventsMarker;Trait Implementations
Sourceimpl Clone for EventsMarker
impl Clone for EventsMarker
Sourcefn clone(&self) -> EventsMarker
fn clone(&self) -> EventsMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EventsMarker
Sourceimpl Debug for EventsMarker
impl Debug for EventsMarker
impl Eq for EventsMarker
Sourceimpl Hash for EventsMarker
impl Hash for EventsMarker
Sourceimpl Ord for EventsMarker
impl Ord for EventsMarker
Sourcefn cmp(&self, other: &EventsMarker) -> Ordering
fn cmp(&self, other: &EventsMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for EventsMarker
impl PartialEq for EventsMarker
Sourceimpl PartialOrd for EventsMarker
impl PartialOrd for EventsMarker
Sourceimpl ProtocolMarker for EventsMarker
impl ProtocolMarker for EventsMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) Events"
const DEBUG_NAME: &'static str = "(anonymous) Events"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = EventsProxy
type Proxy = EventsProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = EventsRequestStream
type RequestStream = EventsRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = EventsSynchronousProxy
type SynchronousProxy = EventsSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for EventsMarker