#[repr(C)]pub struct FunctionDescriptor {
pub interface_class: u8,
pub interface_subclass: u8,
pub interface_protocol: u8,
}Fields
interface_class: u8interface_subclass: u8interface_protocol: u8Trait Implementations
Sourceimpl Clone for FunctionDescriptor
impl Clone for FunctionDescriptor
Sourcefn clone(&self) -> FunctionDescriptor
fn clone(&self) -> FunctionDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FunctionDescriptor
Sourceimpl Debug for FunctionDescriptor
impl Debug for FunctionDescriptor
Sourceimpl<D> Decode<FunctionDescriptor, D> for FunctionDescriptorwhere
D: ResourceDialect,
impl<D> Decode<FunctionDescriptor, D> for FunctionDescriptorwhere
D: ResourceDialect,
Sourcefn new_empty() -> FunctionDescriptor
fn new_empty() -> FunctionDescriptor
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<FunctionDescriptor, D> for &FunctionDescriptorwhere
D: ResourceDialect,
impl<D> Encode<FunctionDescriptor, D> for &FunctionDescriptorwhere
D: ResourceDialect,
impl Eq for FunctionDescriptor
Sourceimpl Hash for FunctionDescriptor
impl Hash for FunctionDescriptor
Sourceimpl Ord for FunctionDescriptor
impl Ord for FunctionDescriptor
Sourcefn cmp(&self, other: &FunctionDescriptor) -> Ordering
fn cmp(&self, other: &FunctionDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for FunctionDescriptor
impl PartialEq for FunctionDescriptor
Sourceimpl PartialOrd for FunctionDescriptor
impl PartialOrd for FunctionDescriptor
impl Persistable for FunctionDescriptor
impl StructuralPartialEq for FunctionDescriptor
Sourceimpl TypeMarker for FunctionDescriptor
impl TypeMarker for FunctionDescriptor
Sourcetype Owned = FunctionDescriptor
type Owned = FunctionDescriptor
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for FunctionDescriptor
impl ValueTypeMarker for FunctionDescriptor
Sourcetype Borrowed<'a> = &'a FunctionDescriptor
type Borrowed<'a> = &'a FunctionDescriptor
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<FunctionDescriptor as TypeMarker>::Owned,
) -> <FunctionDescriptor as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<FunctionDescriptor as TypeMarker>::Owned, ) -> <FunctionDescriptor as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for FunctionDescriptor
impl RefUnwindSafe for FunctionDescriptor
impl Send for FunctionDescriptor
impl Sync for FunctionDescriptor
impl Unpin for FunctionDescriptor
impl UnsafeUnpin for FunctionDescriptor
impl UnwindSafe for FunctionDescriptor